@@ -26,6 +26,8 @@ class PageParser(Parser):
         self.end_date = user_config['end_date']
         self.page = page
         self.url = 'https://weibo.cn/%s?page=%d' % (self.user_uri, page)
+        self.url = "https://weibo.cn/%s/profile?page=%d" % (self.user_uri,
+                                                            page)
         if self.end_date != 'now':
             since_date = self.since_date.split(' ')[0].split('-')
             end_date = self.end_date.split(' ')[0].split('-')
